@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Colin Ian King 2015-2025
+ * Copyright (C) Colin Ian King 2015-2026
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1015,7 +1015,7 @@ static inline void show_key(void)
 	banner(LINES - 1);
 	if (g.view == VIEW_PAGE) {
 		(void)wattrset(g.mainwin, COLOR_PAIR(WHITE_BLUE) | A_BOLD);
-		(void)mvwprintw(g.mainwin, LINES - 1, 0, "Page View, KEY: ");
+		(void)mvwprintw(g.mainwin, LINES - 1, 0, "Page View: ");
 		(void)wattrset(g.mainwin, COLOR_PAIR(WHITE_RED));
 		(void)wprintw(g.mainwin, "A");
 		(void)wattrset(g.mainwin, COLOR_PAIR(WHITE_BLUE) | A_BOLD);
@@ -1461,6 +1461,7 @@ int main(int argc, char **argv)
 				map->name[0] == '\0' ?
 					"[Anonymous]" : basename(map->name));
 		}
+		(void)mvwprintw(g.mainwin, 0, COLS - 20, " PID %7d", g.pid);
 		(void)mvwprintw(g.mainwin, 0, COLS - 8, " %6.1f%%", percent);
 
 		(void)wrefresh(g.mainwin);
